==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/store/ReactComponentAdapter.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/store/ReactComponentAdapter.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dom', './ConnectedComponent.es', './StateProvider.es', './StoreContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.getConnectedReactComponentAdapter = getConnectedReactComponentAdapter;
  exports["default"] = void 0;

  var _icon = require("@frontend-taglib-clay$clayui/icon");

  var _metalComponent = require("frontend-js-metal-web$metal-component");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _reactDom = _interopRequireDefault(require("frontend-js-react-web$react-dom"));

  var _ConnectedComponent = require("./ConnectedComponent.es");

  var _StateProvider = _interopRequireDefault(require("./StateProvider.es"));

  var _StoreContext = require("./StoreContext.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  function getConnectedReactComponentAdapter(ReactComponent, templates) {
    var ReactComponentAdapter =
    /*#__PURE__*/
    function (_Component) {
      _inherits(ReactComponentAdapter, _Component);

      function ReactComponentAdapter() {
        _classCallCheck(this, ReactComponentAdapter);

        return _possibleConstructorReturn(this, _getPrototypeOf(ReactComponentAdapter).apply(this, arguments));
      }

      _createClass(ReactComponentAdapter, [{
        key: "disposed",
        value: function disposed() {
          _reactDom["default"].unmountComponentAtNode(this.refs.app);
        }
      }, {
        key: "syncStore",
        value: function syncStore(store, prevStore) {
          if (store && store !== prevStore) {
            this._mountApp();
          }
        }
      }, {
        key: "_mountApp",
        value: function _mountApp() {
          _reactDom["default"].unmountComponentAtNode(this.refs.app); // eslint-disable-next-line liferay-portal/no-react-dom-render


          _reactDom["default"].render(_react["default"].createElement(_icon.ClayIconSpriteContext.Provider, {
            value: this.store.getState().spritemap
          }, _react["default"].createElement(_StoreContext.StoreContext.Provider, {
            value: this.store
          }, _react["default"].createElement(_StateProvider["default"], null, _react["default"].createElement(ReactComponent, null)))), this.refs.app);
        }
      }]);

      return ReactComponentAdapter;
    }(_metalComponent.Component);

    var ConnectedReactComponentAdapter = (0, _ConnectedComponent.getConnectedComponent)(ReactComponentAdapter, []);

    _metalSoy["default"].register(ConnectedReactComponentAdapter, templates);

    return ConnectedReactComponentAdapter;
  }

  var _default = getConnectedReactComponentAdapter;
  exports["default"] = _default;
  //# sourceMappingURL=ReactComponentAdapter.es.js.map
});
//# sourceMappingURL=ReactComponentAdapter.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/store/ReactComponentAdapter.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/store/ReactComponentAdapter.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dom', './ConnectedComponent.es', './StateProvider.es', './StoreContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.getConnectedReactComponentAdapter = getConnectedReactComponentAdapter;
  exports["default"] = void 0;

  var _icon = require("@frontend-taglib-clay$clayui/icon");

  var _metalComponent = require("frontend-js-metal-web$metal-component");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _reactDom = _interopRequireDefault(require("frontend-js-react-web$react-dom"));

  var _ConnectedComponent = require("./ConnectedComponent.es");

  var _StateProvider = _interopRequireDefault(require("./StateProvider.es"));

  var _StoreContext = require("./StoreContext.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  function getConnectedReactComponentAdapter(ReactComponent, templates) {
    var ReactComponentAdapter = /*#__PURE__*/function (_Component) {
      _inherits(ReactComponentAdapter, _Component);

      function ReactComponentAdapter() {
        _classCallCheck(this, ReactComponentAdapter);

        return _possibleConstructorReturn(this, _getPrototypeOf(ReactComponentAdapter).apply(this, arguments));
      }

      _createClass(ReactComponentAdapter, [{
        key: "disposed",
        value: function disposed() {
          _reactDom["default"].unmountComponentAtNode(this.refs.app);
        }
      }, {
        key: "syncStore",
        value: function syncStore(store, prevStore) {
          if (store && store !== prevStore) {
            this._mountApp();
          }
        }
      }, {
        key: "_mountApp",
        value: function _mountApp() {
          _reactDom["default"].unmountComponentAtNode(this.refs.app); // eslint-disable-next-line liferay-portal/no-react-dom-render


          _reactDom["default"].render(_react["default"].createElement(_icon.ClayIconSpriteContext.Provider, {
            value: this.store.getState().spritemap
          }, _react["default"].createElement(_StoreContext.StoreContext.Provider, {
            value: this.store
          }, _react["default"].createElement(_StateProvider["default"], null, _react["default"].createElement(ReactComponent, null)))), this.refs.app);
        }
      }]);

      return ReactComponentAdapter;
    }(_metalComponent.Component);

    var ConnectedReactComponentAdapter = (0, _ConnectedComponent.getConnectedComponent)(ReactComponentAdapter, []);

    _metalSoy["default"].register(ConnectedReactComponentAdapter, templates);

    return ConnectedReactComponentAdapter;
  }

  var _default = getConnectedReactComponentAdapter;
  exports["default"] = _default;
  //# sourceMappingURL=ReactComponentAdapter.es.js.map
});
//# sourceMappingURL=ReactComponentAdapter.es.js.map
